@@ -1,12 +1,10 @@
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 from telecomlib import shell
-from telecomlib import ip_tools
+from telecomlib import getip
 from telecomlib import star
 
 __all__ = [
     "__version__",
-    "shell",
-    "ip_tools",
-    "star"
+    "shell"
 ]
